Navigation

Struct Navigation 

pub struct Navigation<R>
where R: Routable + Clone + 'static,
{ pub go_back: Callback<()>, pub go_forward: Callback<()>, pub _marker: PhantomData<R>, }
Navigation callbacks for programmatic route manipulation.

Provides pre-built callbacks for:

  • Pushing new routes onto history
  • Replacing current route
  • Navigating back/forward

This struct is created by use_navigation and contains all the callbacks needed for navigation without storing state.

Fields

go_back: Callback<()>

Callback to navigate back in history.

go_forward: Callback<()>

Callback to navigate forward in history.

_marker: PhantomData<R>

Phantom marker for the route type.

Implementations

Source

impl<R> Navigation<R>
where R: Routable + Clone + 'static,

pub fn push_callback(&self, route: R) -> Callback<()>

Create a callback for pushing a route onto history.

pub fn replace_callback(&self, route: R) -> Callback<()>

Create a callback for replacing the current route.

pub fn go_callback(&self, delta: isize) -> Callback<()>

Create a callback for navigating with a delta.